@@ -1,17 +1,17 @@
-import requests
+import requests as requests_http
 from . import utils
 from speakeasy.models import operations, shared
 from typing import Optional
 
 class Apis:
-    _client: requests.Session
-    _security_client: requests.Session
+    _client: requests_http.Session
+    _security_client: requests_http.Session
     _server_url: str
     _language: str
     _sdk_version: str
     _gen_version: str
 
-    def __init__(self, client: requests.Session, security_client: requests.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
+    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
         self._client = client
         self._security_client = security_client
         self._server_url = server_url
@@ -26,7 +26,7 @@ class Apis:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}', request.path_params)
+        url = utils.generate_url(operations.DeleteAPIRequest, base_url, '/v1/apis/{apiID}/version/{versionID}', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -46,6 +46,7 @@ class Apis:
                 res.error = out
 
         return res
+
     def generate_open_api_spec(self, request: operations.GenerateOpenAPISpecRequest) -> operations.GenerateOpenAPISpecResponse:
         r"""Generate an OpenAPI specification for a particular Api.
         This endpoint will generate any missing operations in any registered OpenAPI document if the operation does not already exist in the document.
@@ -54,7 +55,7 @@ class Apis:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/generate/openapi', request.path_params)
+        url = utils.generate_url(operations.GenerateOpenAPISpecRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/generate/openapi', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -76,6 +77,7 @@ class Apis:
                 res.error = out
 
         return res
+
     def generate_postman_collection(self, request: operations.GeneratePostmanCollectionRequest) -> operations.GeneratePostmanCollectionResponse:
         r"""Generate a Postman collection for a particular Api.
         Generates a postman collection containing all endpoints for a particular API. Includes variables produced for any path/query/header parameters included in the OpenAPI document.
@@ -83,7 +85,7 @@ class Apis:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/generate/postman', request.path_params)
+        url = utils.generate_url(operations.GeneratePostmanCollectionRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/generate/postman', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -104,6 +106,7 @@ class Apis:
                 res.error = out
 
         return res
+
     def get_all_api_versions(self, request: operations.GetAllAPIVersionsRequest) -> operations.GetAllAPIVersionsResponse:
         r"""Get all Api versions for a particular ApiEndpoint.
         Get all Api versions for a particular ApiEndpoint.
@@ -112,10 +115,10 @@ class Apis:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}', request.path_params)
+        url = utils.generate_url(operations.GetAllAPIVersionsRequest, base_url, '/v1/apis/{apiID}', request)
         
         headers = {}
-        query_params = utils.get_query_params(request.query_params)
+        query_params = utils.get_query_params(operations.GetAllAPIVersionsRequest, request)
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
         
         client = self._security_client
@@ -135,6 +138,7 @@ class Apis:
                 res.error = out
 
         return res
+
     def get_apis(self, request: operations.GetApisRequest) -> operations.GetApisResponse:
         r"""Get a list of Apis for a given workspace
         Get a list of all Apis and their versions for a given workspace.
@@ -146,7 +150,7 @@ class Apis:
         url = base_url.removesuffix('/') + '/v1/apis'
         
         headers = {}
-        query_params = utils.get_query_params(request.query_params)
+        query_params = utils.get_query_params(operations.GetApisRequest, request)
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
         
         client = self._security_client
@@ -166,6 +170,7 @@ class Apis:
                 res.error = out
 
         return res
+
     def upsert_api(self, request: operations.UpsertAPIRequest) -> operations.UpsertAPIResponse:
         r"""Upsert an Api
         Upsert an Api. If the Api does not exist, it will be created.
@@ -174,10 +179,10 @@ class Apis:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}', request.path_params)
+        url = utils.generate_url(operations.UpsertAPIRequest, base_url, '/v1/apis/{apiID}', request)
         
         headers = {}
-        req_content_type, data, form = utils.serialize_request_body(request)
+        req_content_type, data, form = utils.serialize_request_body(request, "api_input", 'json')
         if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
             headers['content-type'] = req_content_type
         if data is None and form is None:
@@ -201,4 +206,5 @@ class Apis:
                 res.error = out
 
         return res
+
     
\ No newline at end of file
