@@ -1,19 +1,14 @@
 from __future__ import annotations
 import dataclasses
-import requests
+import requests as requests_http
 from ..shared import apiendpoint as shared_apiendpoint
 from ..shared import error as shared_error
 from typing import Optional
 
 
-@dataclasses.dataclass
-class GetAllAPIEndpointsPathParams:
-    api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
-    
-
 @dataclasses.dataclass
 class GetAllAPIEndpointsRequest:
-    path_params: GetAllAPIEndpointsPathParams = dataclasses.field()
+    api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     
 
 @dataclasses.dataclass
@@ -22,5 +17,5 @@ class GetAllAPIEndpointsResponse:
     status_code: int = dataclasses.field()
     api_endpoints: Optional[list[shared_apiendpoint.APIEndpoint]] = dataclasses.field(default=None)
     error: Optional[shared_error.Error] = dataclasses.field(default=None)
-    raw_response: Optional[requests.Response] = dataclasses.field(default=None)
+    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
     
\ No newline at end of file
