@@ -7,16 +7,11 @@ from typing import Optional
 
 
 @dataclasses.dataclass
-class GetAllForVersionAPIEndpointsPathParams:
+class GetAllForVersionAPIEndpointsRequest:
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
     
 
-@dataclasses.dataclass
-class GetAllForVersionAPIEndpointsRequest:
-    path_params: GetAllForVersionAPIEndpointsPathParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class GetAllForVersionAPIEndpointsResponse:
     content_type: str = dataclasses.field()
