@@ -7,16 +7,11 @@ from typing import Optional
 
 
 @dataclasses.dataclass
-class GetSchemasPathParams:
+class GetSchemasRequest:
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
     
 
-@dataclasses.dataclass
-class GetSchemasRequest:
-    path_params: GetSchemasPathParams = dataclasses.field()
-    
-
 @dataclasses.dataclass
 class GetSchemasResponse:
     content_type: str = dataclasses.field()
