@@ -1,21 +1,16 @@
 from __future__ import annotations
 import dataclasses
-import requests
+import requests as requests_http
 from ..shared import error as shared_error
 from ..shared import versionmetadata as shared_versionmetadata
 from typing import Optional
 
 
 @dataclasses.dataclass
-class InsertVersionMetadataPathParams:
+class InsertVersionMetadataRequest:
     api_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'apiID', 'style': 'simple', 'explode': False }})
     version_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'versionID', 'style': 'simple', 'explode': False }})
-    
-
-@dataclasses.dataclass
-class InsertVersionMetadataRequest:
-    path_params: InsertVersionMetadataPathParams = dataclasses.field()
-    request: shared_versionmetadata.VersionMetadataInput = dataclasses.field(metadata={'request': { 'media_type': 'application/json' }})
+    version_metadata_input: shared_versionmetadata.VersionMetadataInput = dataclasses.field(metadata={'request': { 'media_type': 'application/json' }})
     
 
 @dataclasses.dataclass
@@ -23,6 +18,6 @@ class InsertVersionMetadataResponse:
     content_type: str = dataclasses.field()
     status_code: int = dataclasses.field()
     error: Optional[shared_error.Error] = dataclasses.field(default=None)
-    raw_response: Optional[requests.Response] = dataclasses.field(default=None)
+    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
     version_metadata: Optional[shared_versionmetadata.VersionMetadata] = dataclasses.field(default=None)
     
\ No newline at end of file
