@@ -1,17 +1,17 @@
-import requests
+import requests as requests_http
 from . import utils
 from speakeasy.models import operations, shared
 from typing import Optional
 
 class Schemas:
-    _client: requests.Session
-    _security_client: requests.Session
+    _client: requests_http.Session
+    _security_client: requests_http.Session
     _server_url: str
     _language: str
     _sdk_version: str
     _gen_version: str
 
-    def __init__(self, client: requests.Session, security_client: requests.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
+    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
         self._client = client
         self._security_client = security_client
         self._server_url = server_url
@@ -25,7 +25,7 @@ class Schemas:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}', request.path_params)
+        url = utils.generate_url(operations.DeleteSchemaRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -52,7 +52,7 @@ class Schemas:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/schema/download', request.path_params)
+        url = utils.generate_url(operations.DownloadSchemaRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/schema/download', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -83,7 +83,7 @@ class Schemas:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}/download', request.path_params)
+        url = utils.generate_url(operations.DownloadSchemaRevisionRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}/download', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -116,7 +116,7 @@ class Schemas:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/schema', request.path_params)
+        url = utils.generate_url(operations.GetSchemaRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/schema', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -145,7 +145,7 @@ class Schemas:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/schema/{baseRevisionID}/diff/{targetRevisionID}', request.path_params)
+        url = utils.generate_url(operations.GetSchemaDiffRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/schema/{baseRevisionID}/diff/{targetRevisionID}', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -176,7 +176,7 @@ class Schemas:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}', request.path_params)
+        url = utils.generate_url(operations.GetSchemaRevisionRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -207,7 +207,7 @@ class Schemas:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/schemas', request.path_params)
+        url = utils.generate_url(operations.GetSchemasRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/schemas', request)
         
         headers = {}
         headers['user-agent'] = f'speakeasy-sdk/{self._language} {self._sdk_version} {self._gen_version}'
@@ -238,10 +238,10 @@ class Schemas:
         
         base_url = self._server_url
         
-        url = utils.generate_url(base_url, '/v1/apis/{apiID}/version/{versionID}/schema', request.path_params)
+        url = utils.generate_url(operations.RegisterSchemaRequest, base_url, '/v1/apis/{apiID}/version/{versionID}/schema', request)
         
         headers = {}
-        req_content_type, data, form = utils.serialize_request_body(request)
+        req_content_type, data, form = utils.serialize_request_body(request, "request_body", 'multipart')
         if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
             headers['content-type'] = req_content_type
         if data is None and form is None:
